@@ -1,25 +1,8 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2017 Paul Sokolovsky
+# SPDX-FileCopyrightText: 2019 Brent Rubell for Adafruit Industries
 #
-# Copyright (c) 2017 Paul Sokolovsky
-# Modified by Brent Rubell for Adafruit Industries, 2019
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `_sha512.py`
 ======================================================
@@ -495,8 +478,7 @@ class sha512:
     name = "sha512"
 
     def __init__(self, s=None):
-        """Constructs a SHA512 hash object.
-        """
+        """Constructs a SHA512 hash object."""
         self._sha = sha_init()
         if s:
             sha_update(self._sha, getbuf(s))
@@ -517,8 +499,7 @@ class sha512:
         return "".join(["%.2x" % i for i in self.digest()])
 
     def copy(self):
-        """Return a copy (“clone”) of the hash object.
-        """
+        """Return a copy (“clone”) of the hash object."""
         new = sha512()
         new._sha = self._sha.copy()
         return new
@@ -530,15 +511,13 @@ class sha384(sha512):
     name = "sha384"
 
     def __init__(self, s=None):
-        """Constructs a SHA224 hash object.
-        """
+        """Constructs a SHA224 hash object."""
         self._sha = sha384_init()
         if s:
             sha_update(self._sha, getbuf(s))
 
     def copy(self):
-        """Return a copy (“clone”) of the hash object.
-        """
+        """Return a copy (“clone”) of the hash object."""
         new = sha384()
         new._sha = self._sha.copy()
         return new
